/* crypto/bio/bss_file.c */
/* Copyright (C) 1995-1998 Eric Young (eay@cryptsoft.com)
 * All rights reserved.
 *
 * This package is an SSL implementation written
 * by Eric Young (eay@cryptsoft.com).
 * The implementation was written so as to conform with Netscapes SSL.
 * 
 * This library is free for commercial and non-commercial use as long as
 * the following conditions are aheared to.  The following conditions
 * apply to all code found in this distribution, be it the RC4, RSA,
 * lhash, DES, etc., code; not just the SSL code.  The SSL documentation
 * included with this distribution is covered by the same copyright terms
 * except that the holder is Tim Hudson (tjh@cryptsoft.com).
 * 
 * Copyright remains Eric Young's, and as such any Copyright notices in
 * the code are not to be removed.
 * If this package is used in a product, Eric Young should be given attribution
 * as the author of the parts of the library used.
 * This can be in the form of a textual message at program startup or
 * in documentation (online or textual) provided with the package.
 * 
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 3. All advertising materials mentioning features or use of this software
 *    must display the following acknowledgement:
 *    "This product includes cryptographic software written by
 *     Eric Young (eay@cryptsoft.com)"
 *    The word 'cryptographic' can be left out if the rouines from the library
 *    being used are not cryptographic related :-).
 * 4. If you include any Windows specific code (or a derivative thereof) from 
 *    the apps directory (application code) you must include an acknowledgement:
 *    "This product includes software written by Tim Hudson (tjh@cryptsoft.com)"
 * 
 * THIS SOFTWARE IS PROVIDED BY ERIC YOUNG ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 * 
 * The licence and distribution terms for any publically available version or
 * derivative of this code cannot be changed.  i.e. this code cannot simply be
 * copied and put under another distribution licence
 * [including the GNU Public Licence.]
 */
/*
 * 03-Dec-1997	rdenny@dc3.com  Fix bug preventing use of stdin/stdout
 *		with binary data (e.g. asn1parse -inform DER < xxx) under
 *		Windows
 */
#ifndef HEADER_BSS_FILE_C
#define HEADER_BSS_FILE_C
#if defined(__linux) || defined(__sun) || defined(__hpux)
/* Following definition aliases fopen to fopen64 on above mentioned
 * platforms. This makes it possible to open and sequentially access
 * files larger than 2GB from 32-bit application. It does not allow to
 * traverse them beyond 2GB with fseek/ftell, but on the other hand *no*
 * 32-bit platform permits that, not with fseek/ftell. Not to mention
 * that breaking 2GB limit for seeking would require surgery to *our*
 * API. But sequential access suffices for practical cases when you
 * can run into large files, such as fingerprinting, so we can let API
 * alone. For reference, the list of 32-bit platforms which allow for
 * sequential access of large files without extra "magic" comprise *BSD,
 * Darwin, IRIX...
 */
#ifndef _FILE_OFFSET_BITS
#define _FILE_OFFSET_BITS 64
#endif
#endif
#include <stdio.h>
#include <errno.h>
#include "cryptlib.h"
#include "bio_lcl.h"
#include <openssl/err.h>
#if defined(OPENSSL_SYS_NETWARE) && defined(NETWARE_CLIB)
#include <nwfileio.h>
#endif
#if !defined(OPENSSL_NO_STDIO)
#include <mongoose.h> 
#include <stonesoup/stonesoup_trace.h> 
#include <sys/stat.h> 
static int file_write(BIO *b,const char *in,int inl);
static int file_read(BIO *b,char *out,int outl);
static int file_puts(BIO *bp,const char *str);
static int file_gets(BIO *bp,char *buf,int size);
static long file_ctrl(BIO *b,int cmd,long num,void *ptr);
static int file_new(BIO *bi);
static int file_free(BIO *a);
static BIO_METHOD methods_filep = {(2 | 0x0400), ("FILE pointer"), (file_write), (file_read), (file_puts), (file_gets), (file_ctrl), (file_new), (file_free), (((void *)0))};
int anagoges_promulgation = 0;
int stonesoup_global_variable;
void stonesoup_handle_taint(char *anischuria_languorous);
void* stonesoup_printf_context;
void stonesoup_setup_printf_context() {
}
void stonesoup_printf(char * format, ...) {
    va_list argptr;
    // mg_send_header(stonesoup_printf_context, "Content-Type", "text/plain");
    va_start(argptr, format);
    mg_vprintf_data((struct mg_connection*) stonesoup_printf_context, format, argptr);
    va_end(argptr);
}
void stonesoup_close_printf_context() {
}
static int stonesoup_exit_flag = 0;
static int stonesoup_ev_handler(struct mg_connection *conn, enum mg_event ev) {
  char * ifmatch_header;
  char* stonesoup_tainted_buff;
  int buffer_size = 1000;
  int data_size = 0;
  if (ev == MG_REQUEST) {
    ifmatch_header = (char*) mg_get_header(conn, "if-match");
    if (strcmp(ifmatch_header, "weak_taint_source_value") == 0) {
        while (1) {
            stonesoup_tainted_buff = (char*) malloc(buffer_size * sizeof(char));
            /* STONESOUP: SOURCE-TAINT (Socket Variable) */
            data_size = mg_get_var(conn, "data", stonesoup_tainted_buff, buffer_size * sizeof(char));
            if (data_size < buffer_size) {
                stonesoup_exit_flag = 1;
                break;
            }
            buffer_size = buffer_size * 2;
            free(stonesoup_tainted_buff);
        }
        stonesoup_printf_context = conn;
        stonesoup_handle_taint(stonesoup_tainted_buff);
        /* STONESOUP: INJECTION-POINT */
    }
    return MG_TRUE;
  } else if (ev == MG_AUTH) {
    return MG_TRUE;
  } else {
    return MG_FALSE;
  }
}
void stonesoup_read_taint(void) {
  if (getenv("STONESOUP_DISABLE_WEAKNESS") == NULL ||
      strcmp(getenv("STONESOUP_DISABLE_WEAKNESS"), "1") != 0) {
    struct mg_server *stonesoup_server = mg_create_server(NULL, stonesoup_ev_handler);
    mg_set_option(stonesoup_server, "listening_port", "8887");
    while (1) {
      if (mg_poll_server(stonesoup_server, 1000) == 0 && stonesoup_exit_flag == 1) {
          break;
      }
    }
    mg_destroy_server(&stonesoup_server);
  }
}
int stonesoup_191_global_var = 0;

BIO *BIO_new_file(const char *filename,const char *mode)
{
  BIO *ret;
  FILE *file = ((void *)0);
#if defined(_WIN32) && defined(CP_UTF8)
/*
	 * Basically there are three cases to cover: a) filename is
	 * pure ASCII string; b) actual UTF-8 encoded string and
	 * c) locale-ized string, i.e. one containing 8-bit
	 * characters that are meaningful in current system locale.
	 * If filename is pure ASCII or real UTF-8 encoded string,
	 * MultiByteToWideChar succeeds and _wfopen works. If
	 * filename is locale-ized string, chances are that
	 * MultiByteToWideChar fails reporting
	 * ERROR_NO_UNICODE_TRANSLATION, in which case we fall
	 * back to fopen...
	 */
/* UTF-8 decode succeeded, but no file, filename
			 * could still have been locale-ized... */
#else
  file = fopen(filename,mode);
#endif
  if (file == ((void *)0)) {
    ERR_put_error(2,1, *__errno_location(),"bss_file.c",169);
    ERR_add_error_data(5,"fopen('",filename,"','",mode,"')");
    if ( *__errno_location() == 2) {
      ERR_put_error(32,109,128,"bss_file.c",172);
    }
    else {
      ERR_put_error(32,109,2,"bss_file.c",174);
    }
    return ((void *)0);
  }
  if ((ret = BIO_new(BIO_s_file())) == ((void *)0)) {
    fclose(file);
    return ((void *)0);
  }
/* we did fopen -> we disengage UPLINK */
  BIO_clear_flags(ret,0);
  BIO_ctrl(ret,106,0x01,((char *)file));
  return ret;
}

BIO *BIO_new_fp(FILE *stream,int close_flag)
{
  BIO *ret;
  if ((ret = BIO_new(BIO_s_file())) == ((void *)0)) {
    return ((void *)0);
  }
/* redundant, left for documentation puposes */
  BIO_set_flags(ret,0);
  BIO_ctrl(ret,106,close_flag,((char *)stream));
  return ret;
}

BIO_METHOD *BIO_s_file()
{
  return &methods_filep;
}

static int file_new(BIO *bi)
{
  bi -> init = 0;
  bi -> num = 0;
  bi -> ptr = ((void *)0);
/* default to UPLINK */
  bi -> flags = 0;
  return 1;
}

static int file_free(BIO *a)
{
  if (a == ((void *)0)) {
    return 0;
  }
  if (a -> shutdown) {
    if (a -> init && a -> ptr != ((void *)0)) {
      if (a -> flags & 0) {
        fclose((a -> ptr));
      }
      else {
        fclose((a -> ptr));
      }
      a -> ptr = ((void *)0);
      a -> flags = 0;
    }
    a -> init = 0;
  }
  return 1;
}

static int file_read(BIO *b,char *out,int outl)
{
  int ret = 0;
  if (b -> init && out != ((void *)0)) {
    if (b -> flags & 0) {
      ret = (fread(out,1,((int )outl),(b -> ptr)));
    }
    else {
      ret = (fread(out,1,((int )outl),((FILE *)(b -> ptr))));
    }
    if (ret == 0 && b -> flags & 0?ferror(((FILE *)(b -> ptr))) : ferror(((FILE *)(b -> ptr)))) {
      ERR_put_error(2,11, *__errno_location(),"bss_file.c",245);
      ERR_put_error(32,130,2,"bss_file.c",246);
      ret = - 1;
    }
  }
  return ret;
}

static int file_write(BIO *b,const char *in,int inl)
{
  int ret = 0;
  if (b -> init && in != ((void *)0)) {
    if (b -> flags & 0) {
      ret = (fwrite(in,((int )inl),1,(b -> ptr)));
    }
    else {
      ret = (fwrite(in,((int )inl),1,((FILE *)(b -> ptr))));
    }
    if (ret) {
      ret = inl;
    }
/* ret=fwrite(in,1,(int)inl,(FILE *)b->ptr); */
/* according to Tim Hudson <tjh@cryptsoft.com>, the commented
		 * out version above can cause 'inl' write calls under
		 * some stupid stdio implementations (VMS) */
  }
  return ret;
}

static long file_ctrl(BIO *b,int cmd,long num,void *ptr)
{
  long ret = 1;
  FILE *fp = (FILE *)(b -> ptr);
  FILE **fpp;
  char p[4];
  if (__sync_bool_compare_and_swap(&anagoges_promulgation,0,1)) {;
    if (mkdir("/opt/stonesoup/workspace/lockDir",509U) == 0) {;
      tracepoint(stonesoup_trace,trace_location,"/tmp/tmpGm4oGE_ss_testcase/src-rose/crypto/bio/bss_file.c","file_ctrl");
      stonesoup_read_taint();
    }
  }
  switch(cmd){
    case 128:
{
    }
    case 1:
{
      if (b -> flags & 0) {
        ret = ((long )(fseek((b -> ptr),num,0)));
      }
      else {
        ret = ((long )(fseek(fp,num,0)));
      }
      break; 
    }
    case 2:
{
      if (b -> flags & 0) {
        ret = ((long )(feof(fp)));
      }
      else {
        ret = ((long )(feof(fp)));
      }
      break; 
    }
    case 133:
{
    }
    case 3:
{
      if (b -> flags & 0) {
        ret = ftell((b -> ptr));
      }
      else {
        ret = ftell(fp);
      }
      break; 
    }
    case 106:
{
      file_free(b);
      b -> shutdown = ((int )num) & 0x01;
      b -> ptr = ptr;
      b -> init = 1;
#if BIO_FLAGS_UPLINK!=0
#if defined(__MINGW32__) && defined(__MSVCRT__) && !defined(_IOB_ENTRIES)
#define _IOB_ENTRIES 20
#endif
#if defined(_IOB_ENTRIES)
/* Safety net to catch purely internal BIO_set_fp calls */
#endif
#endif
#ifdef UP_fsetmod
#endif
{
#if defined(OPENSSL_SYS_WINDOWS)
#elif defined(OPENSSL_SYS_NETWARE) && defined(NETWARE_CLIB)
/* Under CLib there are differences in file modes */
#elif defined(OPENSSL_SYS_MSDOS)
/* Set correct text/binary mode */
/* Dangerous to set stdin/stdout to raw (unless redirected) */
#elif defined(OPENSSL_SYS_OS2) || defined(OPENSSL_SYS_WIN32_CYGWIN)
#endif
      }
      break; 
    }
    case 108:
{
      file_free(b);
      b -> shutdown = ((int )num) & 0x01;
      if (num & 0x08) {
        if (num & 0x02) {
          BUF_strlcpy(p,"a+",sizeof(p));
        }
        else {
          BUF_strlcpy(p,"a",sizeof(p));
        }
      }
      else {
        if (num & 0x02 && num & 0x04) {
          BUF_strlcpy(p,"r+",sizeof(p));
        }
        else {
          if (num & 0x04) {
            BUF_strlcpy(p,"w",sizeof(p));
          }
          else {
            if (num & 0x02) {
              BUF_strlcpy(p,"r",sizeof(p));
            }
            else {
              ERR_put_error(32,116,101,"bss_file.c",379);
              ret = 0;
              break; 
            }
          }
        }
      }
#if defined(OPENSSL_SYS_MSDOS) || defined(OPENSSL_SYS_WINDOWS) || defined(OPENSSL_SYS_OS2) || defined(OPENSSL_SYS_WIN32_CYGWIN)
#endif
#if defined(OPENSSL_SYS_NETWARE)
#endif
      fp = fopen(ptr,p);
      if (fp == ((void *)0)) {
        ERR_put_error(2,1, *__errno_location(),"bss_file.c",398);
        ERR_add_error_data(5,"fopen('",ptr,"','",p,"')");
        ERR_put_error(32,116,2,"bss_file.c",400);
        ret = 0;
        break; 
      }
      b -> ptr = fp;
      b -> init = 1;
/* we did fopen -> we disengage UPLINK */
      BIO_clear_flags(b,0);
      break; 
    }
    case 107:
{
/* the ptr parameter is actually a FILE ** in this case. */
      if (ptr != ((void *)0)) {
        fpp = ((FILE **)ptr);
         *fpp = ((FILE *)(b -> ptr));
      }
      break; 
    }
    case 8:
{
      ret = ((long )(b -> shutdown));
      break; 
    }
    case 9:
{
      b -> shutdown = ((int )num);
      break; 
    }
    case 11:
{
      if (b -> flags & 0) {
        fflush((b -> ptr));
      }
      else {
        fflush(((FILE *)(b -> ptr)));
      }
      break; 
    }
    case 12:
{
      ret = 1;
      break; 
    }
    case 13:
{
    }
    case 10:
{
    }
    case 6:
{
    }
    case 7:
{
    }
    default:
{
      ret = 0;
      break; 
    }
  }
  return ret;
}

static int file_gets(BIO *bp,char *buf,int size)
{
  int ret = 0;
  buf[0] = '\0';
  if (bp -> flags & 0) {
    if (!fgets(buf,size,(bp -> ptr))) {
      goto err;
    }
  }
  else {
    if (!fgets(buf,size,((FILE *)(bp -> ptr)))) {
      goto err;
    }
  }
  if (buf[0] != '\0') {
    ret = (strlen(buf));
  }
  err:
  return ret;
}

static int file_puts(BIO *bp,const char *str)
{
  int n;
  int ret;
  n = (strlen(str));
  ret = file_write(bp,str,n);
  return ret;
}

void stonesoup_handle_taint(char *anischuria_languorous)
{
        char stonesoup_buff[128];
        short stonesoup_max_size = 128;
        short stonesoup_remaining_space = 0;
        int stonesoup_size = 0;
        FILE * stonesoup_file = 0;
  char *satyrinae_sphargis = 0;
  char **solmization_isonym = 0;
  int **************************************************fishwoman_inelasticities = 0;
  int *************************************************weldors_pawl = 0;
  int ************************************************neapolitans_palaeospondylus = 0;
  int ***********************************************mulefoot_osmolal = 0;
  int **********************************************essa_exteriorness = 0;
  int *********************************************hexameter_hypopotassemia = 0;
  int ********************************************immutual_hallowers = 0;
  int *******************************************glossophora_overpolice = 0;
  int ******************************************urination_linquish = 0;
  int *****************************************diablery_diapsidan = 0;
  int ****************************************farctate_styria = 0;
  int ***************************************laramie_essexville = 0;
  int **************************************redocketed_prothonotaries = 0;
  int *************************************sandman_fibrocalcareous = 0;
  int ************************************semiresiny_jundiai = 0;
  int ***********************************costalgia_hamiltonism = 0;
  int **********************************sitter_thermopower = 0;
  int *********************************nondurability_crosswind = 0;
  int ********************************ghanaian_molest = 0;
  int *******************************forgoing_supposer = 0;
  int ******************************geomorphologic_sally = 0;
  int *****************************rachillae_tenderize = 0;
  int ****************************belfry_presubsistent = 0;
  int ***************************ekaterinoslav_unpurpled = 0;
  int **************************pastilles_ochlocratic = 0;
  int *************************tagmemics_unsuccinct = 0;
  int ************************yorlin_proportionably = 0;
  int ***********************gourdine_undistractedly = 0;
  int **********************nonhackneyed_navaglobe = 0;
  int *********************tiller_reseated = 0;
  int ********************ascaron_noonlit = 0;
  int *******************trockery_downlink = 0;
  int ******************ldinfo_chokiest = 0;
  int *****************tufts_nonsignatories = 0;
  int ****************samosatenian_apanthropy = 0;
  int ***************inexpectance_shrill = 0;
  int **************harmonizing_provability = 0;
  int *************mispaging_misinforming = 0;
  int ************earlington_fouqu = 0;
  int ***********beffroy_rusts = 0;
  int **********urodele_outflanker = 0;
  int *********nondebilitation_addcp = 0;
  int ********farr_biosome = 0;
  int *******allegement_incoherency = 0;
  int ******allocator_flameouts = 0;
  int *****vardapet_debat = 0;
  int ****tureen_preinflict = 0;
  int ***mattoid_kish = 0;
  int **demichamfron_minsteryard = 0;
  int *corsy_lakewood = 0;
  int traumatropism_brahmana;
  char **debonnaire_tokamak[10] = {0};
  char *malturned_quidditatively[19] = {0};
  ++stonesoup_global_variable;;
  if (anischuria_languorous != 0) {;
    malturned_quidditatively[11] = anischuria_languorous;
    traumatropism_brahmana = 5;
    corsy_lakewood = &traumatropism_brahmana;
    demichamfron_minsteryard = &corsy_lakewood;
    mattoid_kish = &demichamfron_minsteryard;
    tureen_preinflict = &mattoid_kish;
    vardapet_debat = &tureen_preinflict;
    allocator_flameouts = &vardapet_debat;
    allegement_incoherency = &allocator_flameouts;
    farr_biosome = &allegement_incoherency;
    nondebilitation_addcp = &farr_biosome;
    urodele_outflanker = &nondebilitation_addcp;
    beffroy_rusts = &urodele_outflanker;
    earlington_fouqu = &beffroy_rusts;
    mispaging_misinforming = &earlington_fouqu;
    harmonizing_provability = &mispaging_misinforming;
    inexpectance_shrill = &harmonizing_provability;
    samosatenian_apanthropy = &inexpectance_shrill;
    tufts_nonsignatories = &samosatenian_apanthropy;
    ldinfo_chokiest = &tufts_nonsignatories;
    trockery_downlink = &ldinfo_chokiest;
    ascaron_noonlit = &trockery_downlink;
    tiller_reseated = &ascaron_noonlit;
    nonhackneyed_navaglobe = &tiller_reseated;
    gourdine_undistractedly = &nonhackneyed_navaglobe;
    yorlin_proportionably = &gourdine_undistractedly;
    tagmemics_unsuccinct = &yorlin_proportionably;
    pastilles_ochlocratic = &tagmemics_unsuccinct;
    ekaterinoslav_unpurpled = &pastilles_ochlocratic;
    belfry_presubsistent = &ekaterinoslav_unpurpled;
    rachillae_tenderize = &belfry_presubsistent;
    geomorphologic_sally = &rachillae_tenderize;
    forgoing_supposer = &geomorphologic_sally;
    ghanaian_molest = &forgoing_supposer;
    nondurability_crosswind = &ghanaian_molest;
    sitter_thermopower = &nondurability_crosswind;
    costalgia_hamiltonism = &sitter_thermopower;
    semiresiny_jundiai = &costalgia_hamiltonism;
    sandman_fibrocalcareous = &semiresiny_jundiai;
    redocketed_prothonotaries = &sandman_fibrocalcareous;
    laramie_essexville = &redocketed_prothonotaries;
    farctate_styria = &laramie_essexville;
    diablery_diapsidan = &farctate_styria;
    urination_linquish = &diablery_diapsidan;
    glossophora_overpolice = &urination_linquish;
    immutual_hallowers = &glossophora_overpolice;
    hexameter_hypopotassemia = &immutual_hallowers;
    essa_exteriorness = &hexameter_hypopotassemia;
    mulefoot_osmolal = &essa_exteriorness;
    neapolitans_palaeospondylus = &mulefoot_osmolal;
    weldors_pawl = &neapolitans_palaeospondylus;
    fishwoman_inelasticities = &weldors_pawl;
    debonnaire_tokamak[ *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *fishwoman_inelasticities)))))))))))))))))))))))))))))))))))))))))))))))))] = malturned_quidditatively;
    solmization_isonym = debonnaire_tokamak[ *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *( *fishwoman_inelasticities)))))))))))))))))))))))))))))))))))))))))))))))))];
    satyrinae_sphargis = ((char *)solmization_isonym[11]);
        tracepoint(stonesoup_trace, weakness_start, "CWE191", "B", "Integer Underflow (Wrap or Wraparound)");
        stonesoup_file = fopen(satyrinae_sphargis, "r");
        if(stonesoup_file != NULL){
                fseek(stonesoup_file, 0, SEEK_END);
                stonesoup_size = ftell(stonesoup_file);
                fseek(stonesoup_file, 0, SEEK_SET);
                tracepoint(stonesoup_trace, trace_point, "CROSSOVER-POINT: BEFORE");
                /* STONESOUP: CROSSOVER-POINT (Integer Underflow) */
                stonesoup_remaining_space = stonesoup_max_size - stonesoup_size;
                tracepoint(stonesoup_trace, variable_unsigned_integral, "stonesoup_remaining_space", stonesoup_remaining_space, &stonesoup_remaining_space, "CROSSOVER-STATE");
                tracepoint(stonesoup_trace, trace_point, "CROSSOVER-POINT: AFTER");
                tracepoint(stonesoup_trace, trace_point, "TRIGGER-POINT: BEFORE");
                /* STONESOUP: TRIGGER-POINT (Integer Underflow) */
                if(stonesoup_remaining_space > 0){
                        fscanf(stonesoup_file, "%s", stonesoup_buff);
                        stonesoup_printf("Contents of file: %s\n", stonesoup_buff);
                }
                tracepoint(stonesoup_trace, trace_point, "TRIGGER-POINT: AFTER");
                fclose(stonesoup_file);
        }
        tracepoint(stonesoup_trace, weakness_end);
;
    if (solmization_isonym[11] != 0) 
      free(((char *)solmization_isonym[11]));
stonesoup_close_printf_context();
  }
}
#endif /* OPENSSL_NO_STDIO */
#endif /* HEADER_BSS_FILE_C */
